perl_term_readline_gnu: Perl extension for the GNU Readline/History libraries
=============================================================================

Description
-----------

Perl extension for the GNU Readline/History Library

Available on CPAN

License
-------

The Perl 5 License (Artistic 1 & GPL 1)


Upstream Contact
----------------

Hiroo HAYASHI

